@@ -6,13 +6,13 @@ Mojolicious::Plugin::CGI - Run CGI script from Mojolicious
 
 =head1 VERSION
 
-0.17
+0.18
 
 =head1 DESCRIPTION
 
 This plugin enable L<Mojolicious> to run Perl CGI scripts. It does so by forking
 a new process with a modified environment and reads the STDOUT in a non-blocking
-matter.
+manner.
 
 =head1 SYNOPSIS
 
@@ -62,7 +62,7 @@ use constant DEBUG                => $ENV{MOJO_PLUGIN_CGI_DEBUG} || 0;
 use constant READ                 => 0;
 use constant WRITE                => 1;
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 our %ORIGINAL_ENV = %ENV;
 
 =head1 ATTRIBUTES
@@ -144,10 +144,10 @@ sub emulate_environment {
     REMOTE_USER => $remote_user,
     REQUEST_METHOD  => $req->method,
     SCRIPT_FILENAME => $self->{script},
-    SCRIPT_NAME     => $c->url_for($self->{route}->name),
-    SERVER_ADMIN    => $ENV{USER} || '',
-    SERVER_NAME     => hostname,
-    SERVER_PORT     => $tx->local_port,
+    SCRIPT_NAME     => $c->url_for($self->{route}->name, {path_info => ''})->path->to_string,
+    SERVER_ADMIN => $ENV{USER} || '',
+    SERVER_NAME  => hostname,
+    SERVER_PORT  => $tx->local_port,
     SERVER_PROTOCOL => $req->is_secure ? 'HTTPS' : 'HTTP',    # TODO: Version is missing
     SERVER_SOFTWARE => __PACKAGE__,
   );
